==> Paws-0.33.tar.gz: Paws-0.33/lib/Paws/CloudDirectory/BatchAttachObjectResponse.pm <==
package Paws::CloudDirectory::BatchAttachObjectResponse;
  use Moose;
  has AttachedObjectIdentifier => (is => 'ro', isa => 'Str', request_name => 'attachedObjectIdentifier', traits => ['NameInRequest']);
1;

### main pod documentation begin ###

=head1 NAME

Paws::CloudDirectory::BatchAttachObjectResponse

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::CloudDirectory::BatchAttachObjectResponse object:

  $service_obj->Method(Att1 => { AttachedObjectIdentifier => $value, ..., AttachedObjectIdentifier => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::CloudDirectory::BatchAttachObjectResponse object:

  $result = $service_obj->Method(...);
  $result->Att1->AttachedObjectIdentifier

=head1 DESCRIPTION

Represents the output batch C<AttachObject> response operation.

=head1 ATTRIBUTES


=head2 AttachedObjectIdentifier => Str

  The C<ObjectIdentifier> of the object that has been attached.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::CloudDirectory>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.42.tar.gz: Paws-0.42/lib/Paws/CloudDirectory/BatchAttachObjectResponse.pm <==
package Paws::CloudDirectory::BatchAttachObjectResponse;
  use Moose;
  has AttachedObjectIdentifier => (is => 'ro', isa => 'Str', request_name => 'attachedObjectIdentifier', traits => ['NameInRequest']);
1;

### main pod documentation begin ###

=head1 NAME

Paws::CloudDirectory::BatchAttachObjectResponse

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::CloudDirectory::BatchAttachObjectResponse object:

  $service_obj->Method(Att1 => { AttachedObjectIdentifier => $value, ..., AttachedObjectIdentifier => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::CloudDirectory::BatchAttachObjectResponse object:

  $result = $service_obj->Method(...);
  $result->Att1->AttachedObjectIdentifier

=head1 DESCRIPTION

Represents the output batch AttachObject response operation.

=head1 ATTRIBUTES


=head2 AttachedObjectIdentifier => Str

  The C<ObjectIdentifier> of the object that has been attached.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::CloudDirectory>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
